==> 3.5.12-core.tar: kdepim/korganizer/archivedialog.h <==
/*
    This file is part of KOrganizer.
    Copyright (c) 2000,2001 Cornelius Schumacher <schumacher@kde.org>
    Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.

    As a special exception, permission is given to link this program
    with any edition of Qt, and distribute the resulting executable,
    without including the source code for Qt in the source distribution.
*/
#ifndef _ARCHIVE_DLG
#define _ARCHIVE_DLG

#include <kdialogbase.h>

class TQRadioButton;
class TQComboBox;
class KIntNumInput;
class KURLRequester;
class KDateEdit;
class TQCheckBox;

namespace KCal {
class Calendar;
}
using namespace KCal;

class ArchiveDialog : public KDialogBase
{
    Q_OBJECT
  public:
    ArchiveDialog(Calendar *calendar,TQWidget *parent=0, const char *name=0);
    virtual ~ArchiveDialog();

  signals:
    // connected by KODialogManager to CalendarView
    void eventsDeleted();
    void autoArchivingSettingsModified();

  protected slots:
    void slotEventsDeleted();
    void slotUser1();
    void slotEnableUser1();
    void slotActionChanged();

  private:
    KURLRequester *mArchiveFile;
    KDateEdit *mDateEdit;
    TQCheckBox *mDeleteCb;
    TQRadioButton *mArchiveOnceRB;
    TQRadioButton *mAutoArchiveRB;
    KIntNumInput *mExpiryTimeNumInput;
    TQComboBox *mExpiryUnitsComboBox;
    TQCheckBox *mEvents;
    TQCheckBox *mTodos;

    Calendar *mCalendar;
};

#endif

==> 3.5.13-core.tar: kdepim/korganizer/archivedialog.h <==
/*
    This file is part of KOrganizer.
    Copyright (c) 2000,2001 Cornelius Schumacher <schumacher@kde.org>
    Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.

    As a special exception, permission is given to link this program
    with any edition of TQt, and distribute the resulting executable,
    without including the source code for TQt in the source distribution.
*/
#ifndef _ARCHIVE_DLG
#define _ARCHIVE_DLG

#include <kdialogbase.h>

class TQRadioButton;
class TQComboBox;
class KIntNumInput;
class KURLRequester;
class KDateEdit;
class TQCheckBox;

namespace KCal {
class Calendar;
}
using namespace KCal;

class ArchiveDialog : public KDialogBase
{
    Q_OBJECT
  TQ_OBJECT
  public:
    ArchiveDialog(Calendar *calendar,TQWidget *parent=0, const char *name=0);
    virtual ~ArchiveDialog();

  signals:
    // connected by KODialogManager to CalendarView
    void eventsDeleted();
    void autoArchivingSettingsModified();

  protected slots:
    void slotEventsDeleted();
    void slotUser1();
    void slotEnableUser1();
    void slotActionChanged();

  private:
    KURLRequester *mArchiveFile;
    KDateEdit *mDateEdit;
    TQCheckBox *mDeleteCb;
    TQRadioButton *mArchiveOnceRB;
    TQRadioButton *mAutoArchiveRB;
    KIntNumInput *mExpiryTimeNumInput;
    TQComboBox *mExpiryUnitsComboBox;
    TQCheckBox *mEvents;
    TQCheckBox *mTodos;

    Calendar *mCalendar;
};

#endif
